Module coverage

Module coverage 

Structs

CoverageInfo
The coverage module allows users to place named coverage goals in their code, together with optional conditions. The must engine gathers coverge information about how often a goal was hit, per execution and in aggregate. Users can query coverage information by later checking if a coverage goal was covered (or how often it was covered in aggregate)

Traits

ExecutionObserver

Functions

covered
is_covered

Type Aliases

ExecutionId