Module future

Module future 

Shuttle’s implementation of an async executor, roughly equivalent to futures::executor.

The spawn method spawns a new asynchronous task that the executor will run to completion. The block_on method blocks the current thread on the completion of a future.

Copied over to the Must runtime to allow handling of async calls

Structs

JoinHandle
An owned permission to join on an async task (await its termination).
TwoWayCom

Enums

JoinError
Task failed to execute to completion.
PollerMsg

Functions

block_on
Run a future to completion on the current thread.
spawn
Spawn a new async task that the executor will run to completion.
spawn_with_attributes
Spawn a new async task that the executor will run to completion.