pub fn test<F>(config: Config, f: F, samples: u64) -> f64Expand description
verify tries to systematically explore the state space until completion. For preliminary analysis,
test provides an incomplete exploration strategy. test is not meant to be comprehensive and usually runs with an upper bound on the number
of executions explored