Must’s requirements for types passed as messages
Structs
- Val
- This type is used to signify the type of messages
exchanged between threads as well as the type of
values returned by a thread.
Since we do not know this type in advance, we created
a trait
Messagethat signifies (Clone, Debug, PartialEq) that needs to be derived on such values of typeVal.